-- Craft Mats window handler
-- coding: utf-8 '�

import "Turbine.UI.Lotro"
import "Vinny.Common"

local labelFont = Turbine.UI.Lotro.Font.Verdana14
local foreColor = Turbine.UI.Color( 0.9, 0.9, 0 )
local whiteColor = Turbine.UI.Color( 1.0, 1.0, 1.0 )
local backColor = Turbine.UI.Color( 0.0, 0.0, 0.0 )
local greyColor = Turbine.UI.Color( 0.1, 0.1, 0.1 )
local Button = Turbine.UI.Lotro.GoldButton
local Label = Turbine.UI.Label
local TextBox = Turbine.UI.TextBox
local CheckBox = Turbine.UI.Lotro.CheckBox
local Item = Turbine.UI.Lotro.ShortcutType.Item
local Alias = Turbine.UI.Lotro.ShortcutType.Alias
local Quickslot = Turbine.UI.Lotro.Quickslot
local Qsize = 36
local Drop = "<- Drop crafting item here"

local function Shortcut(id)
	return Turbine.UI.Lotro.Shortcut(Item,"0,0x700"..id)
end

CM_Window = class( Turbine.UI.Lotro.Window )

function CM_Window:AddField(control, text, pos, size)
	local field = control()
	field:SetParent( self )
	if text then field:SetText( text ) end
	field:SetPosition( pos.x,pos.y )
	field:SetSize( size.x,size.y )
	if control==Button or not text then return field end
	field:SetFont( labelFont )
	field:SetForeColor( text=="" and whiteColor or foreColor )
	field:SetBackColor( control==TextBox and greyColor or backColor )
	field:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleLeft )
	return field
end

function CM_Window:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self )

	-- Position the window near the top center of the screen.
	self:SetSize( 340,270 )
--	self:SetBackColor( Turbine.UI.Color() )
	self:SetPosition( (Turbine.UI.Display.GetWidth() - self:GetWidth())/4, self:GetHeight()/2 )
	self:SetText( "Craft Mats" )
	self:SetVisible( false )

	-- Create an icon field
	self.icon = self:AddField(Quickslot, nil, {x=30,y=40}, {x=Qsize,y=Qsize} )
	self.icon:SetBackColor( Turbine.UI.Color( 0.2, 0.2, 0.2 ) )
	local Blank = self.icon:GetShortcut()
	self.icon.ShortcutChanged = function( sender, args )
		local shortcut = sender:GetShortcut()
		local itemType = shortcut:GetType()
		if itemType==0 then return end
		local itemData = shortcut:GetData()
		if sender:IsAltKeyDown() then print("Type="..itemType..", Data="..itemData) end
		if itemType~=Item then sender:SetShortcut(Blank) return end
		local Item = shortcut:GetItem()
		if not Item then error("Item is null.") return end
		local id = itemData:sub(-5)
		if self.id==id then return end
		local item = Mats[id]
		if not item then
			local name = Item:GetName()
			id = RN[name] -- try finding the name
			if not id then
				printe("Unknown crafting item, "..name)
				sender:SetShortcut(Blank)
				self.name:SetText(Drop)
				return
			else item = Mats[id] end
		end
		Next = nil
		CM_window:SetItem( id,item )
		CM_Uses(id,item)
	end

	-- Create a Name field
	self.name = self:AddField(Label, Drop, {x=70,y=40}, {x=250,y=35} )
	self.name:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)

	-- Create a Tier field
	self:AddField(Label, "Tier:", {x=30,y=85}, {x=40,y=16} )
	self.tier = self:AddField(Label, "", {x=70,y=85}, {x=250,y=16} )

	-- Create a Target button
	self.targetButton = self:AddField(Button, "Target", {x=190,y=82}, {x=120,y=20} )
	self.targetButton.Click = function( sender,args )
        local target = player:GetTarget()
		if target then
			local name = target:GetName()
			local oname = name
			if name:sub(1,5)=="Heavy" then name = name:sub(7) 
			elseif name:sub(1,4)=="Rich" and name:sub(6,10)~="Iron " then 
				name = name:sub(6) 
			elseif name:sub(1,5)=="Bount" then name = "Rich Iron Deposit" end
			local id,idt = Items[name] or RN[name]
			if id then
				if type(id)=="table" then
					idt = id
					id = idt[1]
				end
				local item = Mats[id]
				local link = string.format(xlink,id,item.N)
				local str = "0x700"..id
				self.id = "00000"
				self.icon:SetShortcut(Turbine.UI.Lotro.Shortcut(Item,str))
				CM_window:SetItem( id,item )
				if Items[name] then 
					print(oname.." contains "..link) 
					if idt then
						local str = "Rare:"
						for i,v in ipairs(idt) do
							if i>1 then str = str..' '..string.format(xlink,v,Mats[v].N) end
						end
						print(str)
					end
				end
				CM_Uses(id,item)
			else printe("Unknown object, "..name) end
		else printe("No current target.") end
	end

	-- Create a Type field
	self:AddField(Label, "Type:", {x=30,y=110}, {x=45,y=16} )
	self.type = self:AddField(Label, "", {x=70,y=110}, {x=120,y=16} )

	-- Create a Professions button
	self.profButton = self:AddField(Button, "Professions", {x=190,y=110}, {x=120,y=20} )
	self.profButton.Click = function( sender,args )
        CM_Command:Execute("cm","")
	end

	-- Create a Inventory button
	self.invButton = self:AddField(Button, "Add Inventory", {x=30,y=140}, {x=140,y=20} )
	self.invButton.Click = function( sender,args )
        CM_Command:Execute("cmi","")
	end

	-- Create a Inventory listing button
	self.invButton = self:AddField(Button, "List Inventory", {x=190,y=140}, {x=120,y=20} )
	self.invButton.Click = function( sender,args )
        CM_Command:Execute("cmi","a0")
	end

	-- Create a Vault button
	self.vaultButton = self:AddField(Button, "Add Vault", {x=30,y=170}, {x=120,y=20} )
	self.vaultButton.Click = function( sender,args )
        CM_Command:Execute("cmv","")
	end

	-- Create a Shared button
	self.sharedButton = self:AddField(Button, "Add Shared", {x=190,y=170}, {x=120,y=20} )
	self.sharedButton.Click = function( sender,args )
        CM_Command:Execute("cms","")
	end

	-- Create a Metal Shared button
	self.metalButton = self:AddField(Button, "Metal Shared", {x=30,y=200}, {x=140,y=20} )
	self.metalButton.Click = function( sender,args )
        CM_Command:Execute("cms","p0")
	end

	-- Create a Wood Shared button
	self.woodButton = self:AddField(Button, "Wood Shared", {x=190,y=200}, {x=120,y=20} )
	self.woodButton.Click = function( sender,args )
        CM_Command:Execute("cms","f0")
	end

	-- Create an XP Shared button
	self.xpButton = self:AddField(Button, "Craft XP Shared", {x=100,y=230}, {x=150,y=20} )
	self.xpButton.Click = function( sender,args )
        CM_Command:Execute("cms","xp")
	end

end

function CM_Window:SetItem(id,item,xname)
    if not item then item = Mats[id] end
    if not xname then xname = string.format(xlink,id,item.N) end
	self.id = id
	self.item = item
	self.name:SetText( item.N )
	self.tier:SetText(item.T.." ("..Tier[item.T]..")")
	local desc = item.P and Proc[item.P] or "Guild rep item"
	self.type:SetText( desc )
end

CM_window = CM_Window()

-- Set Escape action
CM_window:SetWantsKeyEvents( true )
CM_window.KeyDown = function(sender, args)
	if( args.Action == Turbine.UI.Lotro.Action.Escape ) then
		CM_window:SetVisible( false )
	end
end
